==> qtjambi-qml-debuginfo-macos-6.7.0.jar: sources/QtJambiQml/QQmlEngineExtensionInterface_shell.cpp <==
#include "QQmlEngineExtensionInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlEngineExtensionInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlEngineExtensionInterface")
    QQmlEngineExtensionInterface *_ptr = reinterpret_cast<QQmlEngineExtensionInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlEngineExtensionInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlEngineExtensionInterface_shell) ); }

jmethodID QQmlEngineExtensionInterface_shell::__shell_javaMethod(int pos) const { return QQmlEngineExtensionInterface_shell::__shell()->javaMethod(typeid(QQmlEngineExtensionInterface), pos); }

// emitting (writeShellConstructor)
QQmlEngineExtensionInterface_shell::QQmlEngineExtensionInterface_shell()
    : QQmlEngineExtensionInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlEngineExtensionInterface::QQmlEngineExtensionInterface_shell()", QQmlEngineExtensionInterface_shell::__shell())
    QQmlEngineExtensionInterface_shell::__shell()->constructed(typeid(QQmlEngineExtensionInterface));
}

// emitting (writeShellDestructor)
QQmlEngineExtensionInterface_shell::~QQmlEngineExtensionInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlEngineExtensionInterface::~QQmlEngineExtensionInterface()", QQmlEngineExtensionInterface_shell::__shell())
    QQmlEngineExtensionInterface_shell::__shell()->destructed(typeid(QQmlEngineExtensionInterface));
}

void QQmlEngineExtensionInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlEngineExtensionInterface_shell*>(ptr)->QQmlEngineExtensionInterface_shell::__shell()->tryDeleteShell(typeid(QQmlEngineExtensionInterface));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlEngineExtensionInterface_shell::initializeEngine(QQmlEngine* engine0, const char* uri1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlEngineExtensionInterface::", QQmlEngineExtensionInterface_shell::__shell())
        if(JniEnvironment __jni_env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlEngineExtensionInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_engine0 = qtjambi_cast<jobject>(__jni_env, engine0);
                    jstring __java_uri1 = qtjambi_cast<jstring>(__jni_env, uri1);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_engine0, __java_uri1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QQmlEngineExtensionInterface_shell::__shell()->warnForMethod("QQmlEngineExtensionInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QQmlEngineExtensionInterface::");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlEngineExtensionInterface_access::__qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID engine0, jstring uri1)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QQmlEngine* __qt_engine0 = QtJambiAPI::objectFromNativeId<QQmlEngine>(engine0);
    const char*  __qt_uri1 = qtjambi_cast<const char* >(__jni_env, __qtjambi_scope, uri1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlEngineExtensionInterface::initializeEngine(QQmlEngine * engine, const char * uri)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlEngineExtensionInterface::initializeEngine(QQmlEngine * engine, const char * uri).";
    } else {
        initializeEngine(__qt_engine0, __qt_uri1);
    }
}

// emitting (writeConstructors)
// new QQmlEngineExtensionInterface()
void __qt_construct_QQmlEngineExtensionInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlEngineExtensionInterface()")
    Q_UNUSED(__java_arguments)
    QQmlEngineExtensionInterface *__qt_this = new(__qtjambi_ptr) QQmlEngineExtensionInterface_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QQmlEngineExtensionInterface::QQmlEngineExtensionInterface()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlEngineExtensionInterface_00024Impl_initialize_1native__Lio_qt_qml_QQmlEngineExtensionInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlEngineExtensionInterface::QQmlEngineExtensionInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlEngineExtensionInterface, sizeof(QQmlEngineExtensionInterface_shell), typeid(QQmlEngineExtensionInterface), true, &deleter_QQmlEngineExtensionInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlEngineExtensionInterface_shell
void __qt_destruct_QQmlEngineExtensionInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlEngineExtensionInterface")
    reinterpret_cast<QQmlEngineExtensionInterface_shell*>(ptr)->~QQmlEngineExtensionInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlEngineExtensionInterface::initializeEngine(QQmlEngine*,const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlEngineExtensionInterface_00024Impl_00024ConcreteWrapper_initializeEngine_1native_1QQmlEngine_1ptr_1const_1char_1ptr__JJLjava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID engine0,
 jstring uri1)
{
    QTJAMBI_TRY {
        QQmlEngineExtensionInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlEngineExtensionInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlEngineExtensionInterface::initializeEngine(QQmlEngine*,const char*)", __qt_this)
        static_cast<QQmlEngineExtensionInterface_access*>(__qt_this)->__qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(__jni_env, __this_nativeId, engine0, uri1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlEngineExtensionInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlEngineExtensionInterface>("QQmlEngineExtensionInterface", "io/qt/qml/QQmlEngineExtensionInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "initializeEngine", "(Lio/qt/qml/QQmlEngine;Ljava/lang/String;)V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QQmlEngineExtensionInterface, {
        ConstructorInfo(&__qt_construct_QQmlEngineExtensionInterface, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlEngineExtensionInterface);
    registerSizeOfShell(typeId, sizeof(QQmlEngineExtensionInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlEngineExtensionInterface* _object = dynamic_cast<QQmlEngineExtensionInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlEngineExtensionInterface *object = reinterpret_cast<QQmlEngineExtensionInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlEngineExtensionInterface *object = reinterpret_cast<const QQmlEngineExtensionInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.8.0.jar: sources/QtJambiQml/QQmlEngineExtensionInterface_shell.cpp <==
#include "QQmlEngineExtensionInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlEngineExtensionInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlEngineExtensionInterface")
    QQmlEngineExtensionInterface *_ptr = reinterpret_cast<QQmlEngineExtensionInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlEngineExtensionInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlEngineExtensionInterface_shell) ); }

jmethodID QQmlEngineExtensionInterface_oshell::__shell_javaMethod(int pos) const { return QQmlEngineExtensionInterface_shell::__shell()->javaMethod(typeid(QQmlEngineExtensionInterface), pos); }

// emitting (writeShellDestructor)
QQmlEngineExtensionInterface_shell::~QQmlEngineExtensionInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlEngineExtensionInterface::~QQmlEngineExtensionInterface()", this)
    QQmlEngineExtensionInterface_shell::__shell()->destructed(typeid(QQmlEngineExtensionInterface));
}

// emitting (writeShellConstructor)
QQmlEngineExtensionInterface_shell::QQmlEngineExtensionInterface_shell()
    : QQmlEngineExtensionInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlEngineExtensionInterface::QQmlEngineExtensionInterface_shell()", this)
    QQmlEngineExtensionInterface_shell::__shell()->constructed(typeid(QQmlEngineExtensionInterface));
}

void QQmlEngineExtensionInterface_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlEngineExtensionInterface_oshell*>(ptr)->QQmlEngineExtensionInterface_oshell::__shell()->tryDeleteShell(typeid(QQmlEngineExtensionInterface));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlEngineExtensionInterface_oshell::initializeEngine(QQmlEngine* engine0, const char* uri1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlEngineExtensionInterface::initializeEngine(QQmlEngine*,const char*)", this)
        if (JniEnvironmentExceptionHandler __jni_env{400}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlEngineExtensionInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_engine0 = qtjambi_cast<jobject>(__jni_env, engine0);
                    jstring __java_uri1 = qtjambi_cast<jstring>(__jni_env, uri1);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_engine0, __java_uri1);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlEngineExtensionInterface_shell::__shell()->warnForMethod("QQmlEngineExtensionInterface::initializeEngine(QQmlEngine*,const char*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QQmlEngineExtensionInterface::initializeEngine(QQmlEngine*,const char*)");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlEngineExtensionInterface_access::__qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID engine0, jstring uri1)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QQmlEngine* __qt_engine0 = QtJambiAPI::objectFromNativeId<QQmlEngine>(engine0);
    const char* __qt_uri1 = qtjambi_cast<const char*>(__jni_env, __qtjambi_scope, uri1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlEngineExtensionInterface::initializeEngine(QQmlEngine * engine, const char * uri)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlEngineExtensionInterface::initializeEngine(QQmlEngine * engine, const char * uri).";
    } else {
        initializeEngine(__qt_engine0, __qt_uri1);
    }
}

// emitting (writeConstructors)
// new QQmlEngineExtensionInterface()
void __qt_construct_QQmlEngineExtensionInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlEngineExtensionInterface()")
    Q_UNUSED(__java_arguments)
    QQmlEngineExtensionInterface *__qt_this = new(__qtjambi_ptr) QQmlEngineExtensionInterface_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlEngineExtensionInterface::QQmlEngineExtensionInterface()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlEngineExtensionInterface_00024Impl_initialize_1native__Lio_qt_qml_QQmlEngineExtensionInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlEngineExtensionInterface::QQmlEngineExtensionInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlEngineExtensionInterface, sizeof(QQmlEngineExtensionInterface_shell), typeid(QQmlEngineExtensionInterface), 0, true, &deleter_QQmlEngineExtensionInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlEngineExtensionInterface_shell
void __qt_destruct_QQmlEngineExtensionInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlEngineExtensionInterface")
    reinterpret_cast<QQmlEngineExtensionInterface_shell*>(ptr)->~QQmlEngineExtensionInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlEngineExtensionInterface::initializeEngine(QQmlEngine*,const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlEngineExtensionInterface_00024Impl_00024ConcreteWrapper_initializeEngine_1native_1QQmlEngine_1ptr_1const_1char_1ptr__JJLjava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID engine0,
 jstring uri1)
{
    QTJAMBI_TRY {
        QQmlEngineExtensionInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlEngineExtensionInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlEngineExtensionInterface::initializeEngine(QQmlEngine*,const char*)", __this_nativeId)
        static_cast<QQmlEngineExtensionInterface_access*>(__qt_this)->__qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(__jni_env, __this_nativeId, engine0, uri1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlEngineExtensionInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlEngineExtensionInterface>("QQmlEngineExtensionInterface", "io/qt/qml/QQmlEngineExtensionInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "initializeEngine", "(Lio/qt/qml/QQmlEngine;Ljava/lang/String;)V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlEngineExtensionInterface, {
        ConstructorInfo(&__qt_construct_QQmlEngineExtensionInterface, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlEngineExtensionInterface);
    registerSizeOfShell(typeId, sizeof(QQmlEngineExtensionInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlEngineExtensionInterface* _object = dynamic_cast<QQmlEngineExtensionInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlEngineExtensionInterface *object = reinterpret_cast<QQmlEngineExtensionInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlEngineExtensionInterface *object = reinterpret_cast<const QQmlEngineExtensionInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
